cluster.cells: Cluster cells based on shape

Description Usage Arguments Examples

View source: R/clustercells.R

Description

This function loads ImageJ roi zip files. It returns a list object with rois normalized into coordinate system as well as mother/bud relations.

Usage

1
cluster.cells(yeastCells, K = 3)

Arguments

x

an ROI object from read.ijzip().

THRESHOLD

an integer value specifying the area in pixels needed for an overlap to count as mother/budded relation. Default value is 100.

borderCol

color value for overlap boundary.

Examples

1
2
3
4
filename<-system.file('data/YET629_02_w1L488nm-L561nm_sequence-10000.zip', package='yeast')
roi <- read.ijzip(filename)
yeastCells<-get.buds(roi)
cluster.cells(yeastCells)

maekiniemi/yeastTracker documentation built on June 9, 2020, 1:40 p.m.